import 'dart:io';

import 'package:consoledoctor_vanguard_http/src/vanguard_constants.dart';

class VanguardHttpClientConfig {

  String serverUrl;
  final String appIdentifier;
  final String appName;
  final String deviceID;
  final String deviceName;
  final String deviceModel;
  final String username;
  final bool kiosk;

  VanguardHttpClientConfig({required this.serverUrl, required this.appIdentifier, required this.appName, required this.deviceID, required this.deviceName, required this.deviceModel, this.username = 'Kiosk-User', this.kiosk = true});

  Map<String, dynamic> buildHeaders() {
    var headers = {
      'CD-API': VanguardConstants.apiSecret,
      'x-app-name': appIdentifier,
      'x-service-name': appName,
      'x-deviceid': deviceID,
      'x-platform': Platform.operatingSystem,
      'x-client-hostname': deviceName,
      'x-device': deviceModel,
      'x-vanguard-user': username
    };

    if (kiosk) headers['x-kiosk'] = 'true';

    return headers;
  }

  String buildUrlParams() {
    var params = '?a=$appIdentifier&s=$appName&did=$deviceID&p=${Platform.operatingSystem}&h=$deviceName&d=$deviceModel&u=$username';
    if (kiosk) params += '&k=true';

    return params;
  }
}